@@ -14,15 +14,15 @@ class JSONFormatter(_JSONFormatter):
         :param record: `LogRecord` we got from `JSONFormatter.format()`.
         :return: Dictionary which will be passed to JSON lib.
         """
-        extra['msg'] = message
+        extra['logmsg'] = message
         if 'logcreated' not in extra:
             extra['logcreated'] = record.created
 
         if 'logname' not in extra:
             extra['logname'] = record.name
 
-        if 'levelname' not in extra:
-            extra['levelname'] = record.levelname
+        if 'loglevel' not in extra:
+            extra['loglevel'] = record.levelname
 
         if record.exc_info:
             extra['exc_info'] = self.formatException(record.exc_info)
